@@ -1,12 +1,18 @@
-logprint <- function(msg, checkverbose=FALSE, checkshowmsg=FALSE, preprint="", level="")
+logprint <- function(msg, checkverbose=FALSE, checkshowmsg=FALSE, preprint="", level="", timestamp=TRUE)
 {
   if (identical(msg, magicmsg_first_connection))
     return(invisible())
   
   if ((getval(serverlog) && !checkverbose && !checkshowmsg) || (getval(verbose) && checkverbose) || (getval(showmsg) && checkshowmsg))
   {
-    logmsg <- paste0(preprint, "[", Sys.time(), "]: ", level, ifelse(level=="", "", ": "), msg, "\n")
-    cat(logmsg)
+    if (timestamp)
+      ts <- paste0("[", Sys.time(), "]: ")
+    else
+      ts <- ""
+    
+    logmsg <- paste0(preprint, ts, level, ifelse(level=="", "", ": "), msg, "\n")
+    # cat(logmsg)
+    message(logmsg, appendLF=FALSE)
     logprint_file(logmsg)
   }
   
@@ -17,7 +23,11 @@ logprint <- function(msg, checkverbose=FALSE, checkshowmsg=FALSE, preprint="", l
 
 logfile_init <- function()
 {
-  logfile <- paste0(tools::file_path_as_absolute("~"), "/.remoterserverlog")
+  if (isWindows())
+    prefix <- base::getwd()
+  else
+    prefix <- tools::file_path_as_absolute("~")
+  logfile <- paste0(prefix, "/.remoterserverlog")
   
   if (file.exists(logfile))
     file.remove(logfile)
